	SUBROUTINE ingest_ssmis_tdrr(first_line, nread, nfound,  
     &    	TB, lat, lon, stdtime,
     &		syear, sjday, eyear, ejday, btime,
     &	       	a19v, a19h, a22v, a37v, a37h, a91v, a91h,  
     &    	alat1, alon1, alat2, alon2, alat3, alon3, 
     &          sfc_img, sfc_env, aline, add_oce, add_lnd, cjobid,
     &          do_debug)
C    &          aline, irec)
C
C  History:
C  Sapiano, Jan2009:  added "goto 101" line to correct a bug
C  Vila, Feb2010:     added eyear and ejday to take into account turn into new
C                     day and new year.
C  Nelkin, May 2011:  change "btime" to real*4 (was integer*4) for
C                     compatibility with select_unique
C  Nelkin, May 2011:  make irec a local variable
C  Nelkin, May 2011:  swap roles of irec, iline to properly handle
C                     first_line > 1 (as in cases of overlap with
C                     previous orbit file)
C  Nelkin, May 2011:  change (irec.ge.aline) to (iline.gt.aline) to
C                     allow processing of final scan line
C  Vila, Oct 2011:    new histogram-matching 91 GHz Ta adjustment to SSMI
C                     based on sfc type
C  Nelkin, Oct 2011:  modify Vila's arguments in call surface_db93_petty
C  Nelkin, Oct 2011:  set [1,161] bounds on kindex computations
C  Nelkin, Nov 2011:  pass in add_oce, add_lnd arrays, read in main
C                     program and passed here via subroutine retrieval
C  Nelkin, Nov 2011:  pass in cjobid, do_debug
C  Nelkin, Dec 2011:  modify longitude averaging near dateline
C
      	implicit none
	include	'parameters.inc'


	!==== input parameters =================================================

        integer*2       LAT_SCENES, LON_SCENES      ! lat-lon matrixes
        parameter       (LAT_SCENES=3)
        parameter       (LON_SCENES=3)

	integer*2	year		            !Current year
	integer*2	jday		            !Current julian day
	integer*2	syear		            !Starting year
	integer*2	sjday		            !Starting julian day
        integer*2       eyear                       !year for each scan
        integer*2       ejday                       !julian day for each scan
	integer*2	hrs		            !Starting hour
	integer*2	mns		            !Starting minute
	real*4    	btime(MAX_SCANS)            !Time for each scan starting					 	    !from current day in seconds

	real*4          secsoday		    ! secsoday = btime	
	real*4 		a19v(NPIX/2,MAX_SCANS)      !array 19V data in kelvin
	real*4 		a19h(NPIX/2,MAX_SCANS)      !array 19H data in kelvin
	real*4 		a22v(NPIX/2,MAX_SCANS)      !array 22V data in kelvin
	real*4 		a37v(NPIX/2,MAX_SCANS)      !array 37V data in kelvin
	real*4 		a37h(NPIX/2,MAX_SCANS)      !array 37H data in kelvin
	
	real*4 		a91v(NPIX,MAX_SCANS)        !array 91V data in kelvin
	real*4 		a91h(NPIX,MAX_SCANS)        !array 91h data in kelvin

	integer*2	sfc_img(NPIX,MAX_SCANS)     !sfc tag for imaging
	real*4 		alat1(NPIX,MAX_SCANS)       !array of latitude in degree
	real*4 		alon1(NPIX,MAX_SCANS)       !array of longitude in degree

	integer*2	sfc_env(NPIX/2,MAX_SCANS)   !sfc tag for environmental
	real*4 		alat2(NPIX/2,MAX_SCANS)     !array of latitude in degree
	real*4 		alon2(NPIX/2,MAX_SCANS)     !array of longitude in degree

	real*4 		alat3(NPIX/2,MAX_SCANS)     !array of latitude in degree
	real*4 		alon3(NPIX/2,MAX_SCANS)     !array of longitude in degree
	
	integer*4 	aline			!total # of scan lines in this file
	
	integer*4	first_line, nread	!start line and how many requested # of lines
	
	! ==== both input/output variable to keep track of lines process =====
	integer*4	irec
	
	! ==== helper variables ====
	integer*4 	iline, i, j, k, l, ichan, n
	real*4		TA(NPIX,MAX_SCANS,NCHAN)
	real*4		dlat, dlon
        real*4		xlon1, xlon2, xavg

        !=== lut variables (histogram matching SSMI-SSMIS) ===
CC      character*256   coeff_file
        REAL*4  ADD_OCE(161,7),ADD_LND(161,7)
CC      REAL*4  SSMIS_OCE(161),SSMIS_LND(161)
        integer*2 kindex
                                                              
        !=== Petty mask ===
        real*4          dummy_mask(1440,720)
        integer*1       sfctype(NPIX, MAX_SCANS)
        integer*1       sfckind(NPIX, MAX_SCANS)
        logical         do_debug
        character*256   cjobid

	!===== output parameters.=============================================
	integer*4	nfound			!actual found lines	
	real*4 		lat(NPIX,MAX_SCANS,LAT_SCENES)
	real*4		lon(NPIX,MAX_SCANS,LON_SCENES)
	real*4		TB(NPIX,MAX_SCANS,NCHAN)
	integer*2 	stdtime(MAX_SCANS, 6), time(6)
	
	!===== parameters used to convert TA to TB.=============================
      	real*4  AP19V,AP19H,AP22V,AP37V,AP37H,AP85V,AP85H,BP19V,BP19H,
     &  	BP22V,BP37V,BP37H,BP85V,BP85H
     
        !===== parameters based on SSMI channels====

	data    AP19V/.969/,AP19H/.969/,AP22V/.974/,AP37V/.986/,
     &          AP37H/.986/,AP85V/.988/,AP85H/.988/,BP19V/.00473/,
     &          BP19H/.00415/,BP22V/.0107/,
     &          BP37V/.0217/,BP37H/.02612/,BP85V/.01383/,BP85H/.01947/

C       !===== parameters based on Yan paper (provided by S. Swadley)
C      	
C	data    AP19V/0.972/,AP19H/.968/,AP22V/.982/,AP37V/.985/,
C     &		AP37H/.981/,AP85V/.982/,AP85H/.978/,BP19V/.00441/,
C     &		BP19H/.00503/,BP22V/.00292/,
C     & 		BP37V/.00415/,BP37H/.00343/,BP85V/.01319/,BP85H/.01876/
C	
	real*4  C19V,C19H,C22V,CC37V,C37H,CC85V,C85H 
	real*4  D19V,D19H,D22V,D37V,D37H,D85V,D85H 
	
       !===== Initialize variables ============================================

        do i=1,NPIX   
         do j=1,MAX_SCANS

          do k=1,NCHAN
           TA(i,j,k)=MISS_FLT
           TB(i,j,k)=MISS_FLT
          enddo

          do l=1,LON_SCENES
           lat(i,j,l)=MISS_FLT
           lon(i,j,l)=MISS_FLT
          enddo

         enddo
        enddo

C      !===== Open LUT files for TA matching ====

CC      COEFF_FILE='ssmis_lut_files/lut_add_ocean'
CC      OPEN(UNIT=20,FILE=COEFF_FILE, STATUS='OLD')
CC      DO i=1,161
CC      READ (20,FMT='(f6.2,7(f7.2))')SSMIS_OCE(I),(ADD_OCE(I,J),J=1,7)
CC      END DO
CC      CLOSE (20)

CC      COEFF_FILE='ssmis_lut_files/lut_add_land'
CC      OPEN(UNIT=20,FILE=COEFF_FILE, STATUS='OLD')
CC      DO i=1,161
CC      READ (20,FMT='(f6.2,7(f7.2))')SSMIS_LND(I),(ADD_LND(I,J),J=1,7)
CC      END DO
CC      CLOSE (20)

        !===== Open sea/land mask (db93-Petty)====

c       call surface_db93_petty(first_line, aline,
        call surface_db93_petty(cjobid, aline,
     &             dummy_mask, alat1, alon1, sfctype, sfckind, do_debug)

	!===== define variable used in conversion ====


	C19V = 1/(AP19V*(1-BP19V))
      	C19H = 1/(AP19H*(1-BP19H))
      	C22V = 1/(AP22V*(1-BP22V))
      	CC37V = 1/(AP37V*(1-BP37V))
      	C37H = 1/(AP37H*(1-BP37H))
      	CC85V = 1/(AP85V*(1-BP85V))
      	C85H = 1/(AP85H*(1-BP85H))
      	D19V = C19V*BP19V
      	D19H = C19H*BP19H
      	D22V = C22V*BP22V
      	D37V = CC37V*BP37V
      	D37H = C37H*BP37H
      	D85V = CC85V*BP85V
      	D85H = C85H*BP85H


cejn	iline=first_line
	irec = first_line - 1  ! increments upon entering do loop
        iline = 0

	do n=1, nread
    	  irec=irec+1
	  iline = iline + 1
	  
	  !end of file or not
	  !if(irec.ge.aline) then
cejn	  if (irec. gt. aline) then
	  if (iline .gt. aline) then
	    nfound = iline-first_line
	    goto 101

	  else  ! iline .le. (aline) 

	    !!!---------- time information-------------------!!!

    	    if ( btime(irec) .ge. 0. ) then
    	      secsoday = btime(irec)
cejn	    if ( btime(iline) .ge. 0. ) then
cejn	      secsoday = btime(iline)

              if (secsoday.gt.43200) then
	      year=syear 
	      jday=sjday
	      else
	      year=eyear
	      jday=ejday
	      endif
	      
	      call convStdtime(year, jday, secsoday, time)

	      do j = 1, 6
	        stdtime(iline, j) = time(j)
	      end do
cejn debug
c               write(511,*) iline, (stdtime(iline,j), j=1,6)

	    else
  
	      do j = 1, 6
	        stdtime(iline, j) = MISS_INT
	      end do

	    end if
	    !!!----------------------------------------------!!!
	  
	    do i=1,NPIX   

	      lat(i,iline,1)  = alat1(i,irec)
	      lon(i,iline,1)  = alon1(i,irec)

              ! --- histogram matching applied --------------!

              kindex=nint(a91h(i,irec))-139
              if (kindex .lt. 1) then
                 kindex = 1
              else if (kindex .gt. 161) then
                 kindex = 161
              endif
              if (sfc_img(i,irec).eq.5) then
              a91h(i,irec) = a91h(i,irec)-add_oce(kindex,7)
              else
              a91h(i,irec) = a91h(i,irec)-add_lnd(kindex,7)
              endif
	      TA(i,iline,6) = a91h(i,irec)

              kindex=nint(a91v(i,irec))-139
              if (kindex .lt. 1) then
                 kindex = 1
              else if (kindex .gt. 161) then
                 kindex = 161
              endif
              if (sfc_img(i,irec).eq.5) then
              a91v(i,irec) = a91v(i,irec)-add_oce(kindex,6)
              else
              a91v(i,irec) = a91v(i,irec)-add_lnd(kindex,6)
              endif
	      TA(i,iline,7) = a91v(i,irec)

              ! --- ta-tb conversion --------------!

	      TB(i,iline,6)=C85H*TA(i,iline,6) - D85H*TA(i,iline,7) 
	      TB(i,iline,7)=CC85V*TA(i,iline,7) - D85V*TA(i,iline,6)	

	    enddo 
	    
	    do i=1,NPIX,2 

	      lat(i,iline,2)    = alat2((i/2)+1,irec)
	      lon(i,iline,2)    = alon2((i/2)+1,irec)
              lat(i+1,iline,2)  = MISS_FLT
  	      lon(i+1,iline,2)  = MISS_FLT

	      lat(i,iline,3)    = alat3((i/2)+1,irec)
	      lon(i,iline,3)    = alon3((i/2)+1,irec)
	      lat(i+1,iline,3)  = MISS_FLT
	      lon(i+1,iline,3)  = MISS_FLT

              ! --- histogram matching applied --------------!

              kindex=nint(a19h((i/2)+1,irec))-139
              if (kindex .lt. 1) then
                 kindex = 1
              else if (kindex .gt. 161) then
                 kindex = 161
              endif
              if (sfc_env((i/2)+1,irec).eq.5) then
              a19h((i/2)+1,irec) = a19h((i/2)+1,irec)-add_oce(kindex,2)
              else
              a19h((i/2)+1,irec) = a19h((i/2)+1,irec)-add_lnd(kindex,2)
              endif
	      TA(i,iline,1)=a19h((i/2)+1,irec)

              kindex=nint(a19v((i/2)+1,irec))-139
              if (kindex .lt. 1) then
                 kindex = 1
              else if (kindex .gt. 161) then
                 kindex = 161
              endif
              if (sfc_env((i/2)+1,irec).eq.5) then
              a19v((i/2)+1,irec) = a19v((i/2)+1,irec)-add_oce(kindex,1)
              else
              a19v((i/2)+1,irec) = a19v((i/2)+1,irec)-add_lnd(kindex,1)
              endif
	      TA(i,iline,2)=a19v((i/2)+1,irec)

              kindex=nint(a22v((i/2)+1,irec))-139
              if (kindex .lt. 1) then
                 kindex = 1
              else if (kindex .gt. 161) then
                 kindex = 161
              endif
              if (sfc_env((i/2)+1,irec).eq.5) then
              a22v((i/2)+1,irec) = a22v((i/2)+1,irec)-add_oce(kindex,3)
              else
              a22v((i/2)+1,irec) = a22v((i/2)+1,irec)-add_lnd(kindex,3)
              endif
	      TA(i,iline,3)=a22v((i/2)+1,irec)

              kindex=nint(a37h((i/2)+1,irec))-139
              if (kindex .lt. 1) then
                 kindex = 1
              else if (kindex .gt. 161) then
                 kindex = 161
              endif
              if (sfc_env((i/2)+1,irec).eq.5) then
              a37h((i/2)+1,irec) = a37h((i/2)+1,irec)-add_oce(kindex,5)
              else
              a37h((i/2)+1,irec) = a37h((i/2)+1,irec)-add_lnd(kindex,5)
              endif
	      TA(i,iline,4)=a37h((i/2)+1,irec)

              kindex=nint(a37v((i/2)+1,irec))-139
              if (kindex .lt. 1) then
                 kindex = 1
              else if (kindex .gt. 161) then
                 kindex = 161
              endif
              if (sfc_env((i/2)+1,irec).eq.5) then
              a37v((i/2)+1,irec) = a37v((i/2)+1,irec)-add_oce(kindex,4)
              else
              a37v((i/2)+1,irec) = a37v((i/2)+1,irec)-add_lnd(kindex,4)
              endif
	      TA(i,iline,5)=a37v((i/2)+1,irec)

              ! --- ta-tb conversion --------------!

	      TB(i,iline,1) = C19H*TA(i,iline,1) - D19H*TA(i,iline,2)
	      TB(i,iline,2) = C19V*TA(i,iline,2) - D19V*TA(i,iline,1)
	      TB(i,iline,3) = C22V*TA(i,iline,3) -
     &			      D22V*(.653*TA(i,iline,1)+96.6)
	      TB(i,iline,4) = C37H*TA(i,iline,4) - D37H*TA(i,iline,5)
	      TB(i,iline,5) = CC37V*TA(i,iline,5) - D37V*TA(i,iline,4)

            enddo

	    do i=1,NPIX,2

 	      do ichan = 1, 5

	        if (i.eq.NPIX-1) then
	        TA(i+1,iline,ichan)=TA(i,iline,ichan)
	        TB(i+1,iline,ichan)=TB(i,iline,ichan)
		else
	        TA(i+1,iline,ichan)=(TA(i,iline,ichan)+
     &                               TA(i+2,iline,ichan))/2
	        TB(i+1,iline,ichan)=(TB(i,iline,ichan)+
     &                               TB(i+2,iline,ichan))/2
		endif

	      end do

	      do ichan = 2, 3

	        if (i.eq.NPIX-1) then
		dlat=lat(i,iline,ichan)-lat(i-1,iline,ichan)
C
C EJN - Account for longitudes straddling the dateline.
C
                   xlon1 = lon(  i,iline,ichan)
                   xlon2 = lon(i-1,iline,ichan)
                   if (xlon1 .LT. -179. .AND. xlon2 .GT. 179.) then
                      xlon2 = xlon2 - 360.
                   else if ( xlon2 .LT.-179. .AND. xlon1 .GT. 179.) then
                      xlon1 = xlon1 - 360.
                   endif
                   dlon = xlon1 - xlon2
CEJN		dlon=lon(i,iline,ichan)-lon(i-1,iline,ichan)
	        lat(i+1,iline,ichan)=lat(i,iline,ichan)+dlat
	        lon(i+1,iline,ichan)=lon(i,iline,ichan)+dlon
		else
	        lat(i+1,iline,ichan)=(lat(i,iline,ichan)+
     &                               lat(i+2,iline,ichan))/2
C
C EJN - Account for longitudes straddling the dateline.
C
                   xlon1 = lon(  i,iline,ichan)
                   xlon2 = lon(i+2,iline,ichan)
                   if (xlon1 .LT. -179. .AND. xlon2 .GT. 179.) then
                      xlon2 = xlon2 - 360. 
                      xavg = (xlon1 + xlon2) / 2.
                      if (xavg .LT. -180.) xavg = xavg + 360.
                      lon(i+1,iline,ichan) = xavg
                   else if ( xlon2 .LT.-179. .AND. xlon1 .GT. 179.) then
                      xlon1 = xlon1 - 360.
                      xavg = (xlon1 + xlon2) / 2.
                      if (xavg .LT. -180.) xavg = xavg + 360.
                      lon(i+1,iline,ichan) = xavg
                   else
                      lon(i+1,iline,ichan)=(lon(i,iline,ichan)+
     +                                     lon(i+2,iline,ichan))/2
                   endif
CEJN	        lon(i+1,iline,ichan)=(lon(i,iline,ichan)+
CEJN &                               lon(i+2,iline,ichan))/2
		endif
C       
C	        TA(i+1,iline,ichan) = MISS_FLT
C	        TB(i+1,iline,ichan) = MISS_FLT
C		
 	      enddo

 	    enddo

cejn	    iline=iline+1
	  
	  endif 
	   	  
	enddo		! end of loop on n
	
	nfound = nread



 101	return

	end
