      ! Write retrieved surface quantities to output hdf file.

      subroutine output_surface_hdf(hdf_outfile,aline,
     &		 hdf_time,hdf_lon, hdf_lat, hdf_rain) 

      implicit none
      include 	'parameters.inc'

C**** Input Variables ************************************************
      character*42    	hdf_outfile
      real	      	hdf_lon(NPIX,MAX_SCANS)
      real	      	hdf_lat(NPIX,MAX_SCANS)      
      real	      	hdf_rain(NPIX,MAX_SCANS)      
      integer*2	      	hdf_time(6,MAX_SCANS)
      integer         	aline
        
C**** Function declaration *******************************************
      integer*4		swopen
      integer*4         swcreate
      integer           swdefdim
      integer     	swdefgfld
      integer     	swdefdfld
      integer           swwrfld
      integer           swdetach
      integer           swclose

      
C**** Variable declaration *******************************************
      
      integer*4         swfid, swid
      integer		status, i, j
      real*4		lon(NPIX), lat(NPIX), rain(NPIX)
      integer*2		time(6)
      
      integer	        start(2)
      integer	        stride(2)
      integer	        count(2), count_line(2), count_time(2)
      integer      	dtrack

      
c**** Open the HDF-EOS file, using "REATE" file access code ********** 
      swfid = swopen(OUTPUT_DIR//hdf_outfile, DFACC_CREATE)
      
c**** Create the swath, "SSMI", within the file **********************
      swid = swcreate(swfid, "SSMI")
      
c**** Define  dimension in swath *************************************
      dtrack=1
      status = swdefdim(swid, "LDIM", dtrack)
      
      dtrack=6
      status = swdefdim(swid, "TDIM", dtrack)
      
      dtrack=NPIX
      status = swdefdim(swid, "XDIM", dtrack )
      
      dtrack=aline
      status = swdefdim(swid, "YDIM", dtrack )
      
c**** Define Geolocation and Data fields *****************************
      status=swdefgfld(swid,"LINES","LDIM", DFNT_INT32,0) 
      
      status = swdefgfld(swid, "Line",
     &         "LDIM,YDIM", DFNT_INT32,0)
      
      status = swdefgfld(swid, "Time",
     &         "TDIM,YDIM", DFNT_INT16,0)
      
      status = swdefgfld(swid, "Longitude",
     &         "XDIM,YDIM", DFNT_FLOAT32,0)

      status = swdefgfld(swid,"Latitude",
     &         "XDIM,YDIM", DFNT_FLOAT32,0)

      status = swdefdfld(swid,"Rain",
     &         "XDIM,YDIM", DFNT_FLOAT32,0)
      
      
c**** Write data *****************************************************      
      
      start(1)  = 0
      stride(1) = 1
      stride(2) = 1
      
      count(1)  = NPIX
      count(2)  = 1
      
      count_line(1) = 1
      count_line(2) = 1
      
      count_time(1) = 6
      count_time(2) = 1
      
      !Total number of scan lines
      status = swwrfld(swid,"LINES",start(1),stride(1),
     &	       count_line(1),aline)
      
      
      do j = 1, aline
        
	start(2) = j - 1
	
	do i=1,6
	  time(i) = hdf_time(i,j)
	enddo
	
	do i=1,NPIX
	  lon(i)  = hdf_lon(i,j)
	  lat(i)  = hdf_lat(i,j)
	  rain(i) = hdf_rain(i,j)
	enddo

        status = swwrfld(swid,"Line",start,stride,count_line, j)	      
        status = swwrfld(swid,"Time",start,stride,count_time,time)	      
        
	status = swwrfld(swid,"Longitude",start,stride,count,lon)	     
        status = swwrfld(swid,"Latitude", start,stride,count,lat)
        status = swwrfld(swid,"Rain",     start,stride,count,rain)
      
      enddo

c**** Detach from the swath ****************************************** 
      status = swdetach(swid)

c**** Close the file ************************************************* 
      status = swclose(swfid)
      
      
      return
      end
   
