      ! Generic quality control.  This will exclude pixels having 
      ! bad brightness temperatures, bad navigation, etc.  This 
      ! subroutine should also exclude scans which occur during times 
      ! at which the satellite data is known to be bad.

      ! Right now, qualctrl should reject all bad pixels, except:
      ! if only the 85V is bad --> pixel_status = 7

      subroutine qualctrl(nwork, Tb, Tc, lat, lon, stdtime,
     &           satname, sfctype, pixel_status)

      implicit none
      include 'parameters.inc'

      integer     nwork
      real        Tb(NPIX, MAX_SCANS, NCHAN)
      real        Tc(NPIX, MAX_SCANS, NCHAN)
      real        lat(NPIX, MAX_SCANS)
      real        lon(NPIX, MAX_SCANS)
      integer*2   stdtime(MAX_SCANS,6)
      character   satname*3
      integer*1   sfctype(NPIX, MAX_SCANS)
      integer*2   pixel_status(NPIX, MAX_SCANS)

      integer     chan, lin, pix, n_months

      real        Tbmin, Tbmax

      data Tbmin, Tbmax / 50.0, 325.0 /

      do lin = 1, nwork
         do pix = 1, NPIX

            ! Check that latitude bounds are within 70N and 70S
            ! The latitude test for .lt. -70 breaks down in the sixth
            ! decimal place (-69.999997), and the ilat calculation for
            ! gridding in output-pathfinder breaks down in the fifth.
            ! The safest solution is to mask out pixels below -69.9999.
            if (lat(pix,lin) .lt. -69.9999) pixel_status(pix,lin) = -25
            if (lat(pix,lin) .gt.  70.)  pixel_status(pix,lin) = -25

            if (lon(pix,lin) .lt. -180.) pixel_status(pix,lin) = -25
            if (lon(pix,lin) .gt.  180.) pixel_status(pix,lin) = -25

c            if (lat(pix,lin) .lt. -16. .or. lat(pix,lin) .gt. -12. .or.
c     $         lon(pix,lin) .lt. -175. .or. lon(pix,lin) .gt. -170.)then 
c               pixel_status(pix,lin) = -25
c            endif

            ! Check time to see if 85V channel was working on F08
            n_months = 12*(stdtime(lin,1)-1987) + stdtime(lin,2) 
            if ((satname .eq. 'F08' ) .and. (n_months .gt. 16)) then 
c               pixel_status(pix,lin) = 7
               call syn85v(Tc(pix,lin,2),Tc(pix,lin,1),Tc(pix,lin,3),
     &         Tc(pix,lin,5),Tc(pix,lin,4),Tc(pix,lin,6),Tc(pix,lin,7))
            end if

            ! Check for valid surface types
            if (sfctype(pix,lin) .lt. 0 )  then
               pixel_status(pix,lin) = -21
               goto 10
            end if

            ! Verify that channel Tb are within valid range.
            if ( pixel_status(pix, lin) .eq. 7 ) then
               do chan = 1, 6
                  if ((Tc(pix,lin,chan) .LT. Tbmin) .OR.
     &                     (Tc(pix,lin,chan) .GT. Tbmax) ) then
                     pixel_status(pix,lin) = -9
                     goto 10
                  end if
               end do
            else
               do chan = 1, NCHAN
                  if ((Tc(pix,lin,chan) .LT. Tbmin) .OR.
     &                     (Tc(pix,lin,chan) .GT. Tbmax) ) then
                     pixel_status(pix,lin) = -9
c       write(*,*) pix,lin,chan,Tc(pix,lin,chan)
                     goto 10
                  end if
               end do
            end if
10       end do
      end do

c      stop
      return
      end

      subroutine syn85v(tb19v,tb19h,tb22v,tb37v,tb37h,tb85h,tb85v)
      save
      real const(7),coef(7,6)
      data (const(i),i=1,7)
     &/67.41051,77.5119,45.79873,21.35738,15.8786,21.97108,42.05072/
      data ((coef(i,j),j=1,6),i=1,7)
     &/ 0.343107,-0.166661, 0.064316, 0.299581,-0.328124, 0.517033,
     & -0.571147, 0.311122, 0.201946, 1.014484,-0.748197, 0.462336,
     &  0.418078,-0.041601,-0.119912, 0.298003,-0.420198, 0.702025,
     & -0.207214, 0.189461,-0.073309, 0.855635,-0.654701, 0.813340,
     & -0.177013, 0.035521, 0.113283, 0.567277,-0.489962, 0.849420,
     & -0.356680, 0.266729,-0.083909, 0.883401,-0.711874, 0.919301,
     &  0.0     , 0.0     ,-0.347921, 0.437676,-0.209622, 0.988095/
C
      AP19V = .969 
      AP19H =.969 
      AP22V =.974   
      AP37V =.986 
      AP37H =.986      
      AP85V = .988 
      AP85H =.988 
      BP19V =.00473 
      BP19H = .00415 
      BP22V=.0107      
      BP37V = .0217 
      BP37H = .02612 
      BP85V =.01383 
      BP85H =.01947      
      C19V = 1/(AP19V*(1-BP19V))      
      C19H = 1/(AP19H*(1-BP19H))      
      C22V = 1/(AP22V*(1-BP22V))      
      C37V = 1/(AP37V*(1-BP37V))      
      C37H = 1/(AP37H*(1-BP37H))      
      C85V = 1/(AP85V*(1-BP85V))      
      C85H = 1/(AP85H*(1-BP85H))      
      D19V = C19V*BP19V      
      D19H = C19H*BP19H      
      D22V = C22V*BP22V      
      D37V = C37V*BP37V      
      D37H = C37H*BP37H      
      D85V = C85V*BP85V      
      D85H = C85H*BP85H      
      ta85h = tb85h-(0.01466*tb85h-0.822)
      ta19v = (C19H*tb19v + D19V*tb19h)/(C19H*C19V - D19V*D19H)      
      ta19h = (D19H*tb19v + C19V*tb19h)/(C19H*C19V - D19V*D19H)      
      ta22v = (tb22v + D22V*(.653*ta19h + 96.6))/C22V      
      ta37v = (C37H*tb37v + D37V*tb37h)/(C37H*C37V - D37V*D37H)      
      ta37h = (D37H*tb37v + C37V*tb37h)/(C37H*C37V - D37V*D37H)  
      tmpdif=ta19h-ta85h
      if(tmpdif .le. -70.0)then
         icat=1
      elseif((-70.0 .lt. tmpdif) .and. (tmpdif .le. -50.0))then
         if(ta85h .le. 210.0)icat=2
         if(ta85h .gt. 210.0)icat=3
      elseif((-50.0 .lt. tmpdif) .and. (tmpdif .le. 0.0))then
         if(ta85h .ge. 180.0)icat=4
         if(ta85h .lt. 180.0)icat=5
      elseif((0.0 .lt. tmpdif) .and. (tmpdif .le. 30.0))then
         icat=6
      else
         icat=7
      endif

      ta85v=const(icat) + coef(icat,1)*ta19v
     &                  + coef(icat,2)*ta19h
     &                  + coef(icat,3)*ta22v
     &                  + coef(icat,4)*ta37v
     &                  + coef(icat,5)*ta37h
     &                  + coef(icat,6)*ta85h

      tb19v = C19V*ta19v - D19V*ta19h
      tb19h = C19H*ta19h - D19H*ta19v
      tb22v = C22V*ta22v - D22V*(.653*ta19h + 96.6)
      tb37v = C37V*ta37v - D37V*ta37h
      tb37h = C37H*ta37h - D37H*ta37v
      tb85h = C85H*ta85h - D85H*ta85v
      tb85v = C85V*ta85v - D85V*ta85h

      return
      end
