	SUBROUTINE READARGS (cinfile, farg1, farg2, farg3, farg4,
     +			     farg5, farg6, farg7, ninfile)
C***********************************************************************
C* READARGS  	Reads the input command line arguments		       *
C*								       *
C* Called by:	L3B42main0ss					       *
C*   								       *
C* Calls:	REPRT_ERROR, GETARG, IARGC, ST_LSTR, ST_CLST,          *
C* 		ST_INLN 					       *
C* READARGS reads the file containing the command-line arguments,      *
C* supplied at the initiation of L3B42main0ss execution.  The 	       *
C* command-line arguments are extracted and parsed from the input file *
C* and passed to the appropriate subroutines.	 		       *
C*  								       *
C* Input Parameters:						       *
C*								       *
C*  cinfile	CHAR	file containing the L3B42main0ss command-line  *
C*			arguments				       *
C* 								       *
C* Output Parameters:						       *
C*								       *
C*   farg1	CHAR	PPS job ID				       *
C*   farg2	CHAR	satellite ID, (e.g., "F17")                    *
C*   farg3	CHAR	names of the input data files, array of        *
C*			dimension (10000)			       *
C*   farg4	CHAR	start time of processing window		       *
C*                      ( YYYYMMDD"T"HH:MM:SS )			       *
C*   farg5	CHAR	end time of processing window		       *
C*			( YYYYMMDD"T"HH:MM:SS )			       *
C*   farg6	CHAR	name of the output directory		       *
C*   farg7	CHAR	flag for dumping debug information	       *
C*   ninfile	INT 	number of input data files                     *
C*			(max 10000)				       *
C**								       *
C* Log:								       *
C* E.Nelkin/SSAI	12/09	First Version, with PPS toolkit API    *
C* E.Nelkin/SSAI	 7/11	Increase ninfile dimension to 10000    *
C* E.Nelkin/SSAI         7/11	Add debug_flag as farg8                *
C* E.Nelkin/SSAI        10/11	Updated Output Parameters documentation*
C* E.Nelkin/SSAI        10/11	Added error checks on ST_LSTR          *
C* E.Nelkin/SSAI         9/12   Non-PPS version for Bob Joyce          *
C***********************************************************************
C
	IMPLICIT	NONE
C
	INTEGER*4	IARGC, nargs, iunit, ios, icount, iret,
     +			i, ninfile, nin, l_key,
     +			l_parm, length
C
	CHARACTER*1	cdummy, farg7
	CHARACTER*17	farg4, farg5
	CHARACTER*256	cinfile, cstring, ckp(2)
c	CHARACTER*96	farg0, farg3(10000)
c      	CHARACTER*93	farg0, farg3(10000)
       	CHARACTER*65	farg0, farg3(10000)
	CHARACTER*256	farg1, farg2, farg6
	CHARACTER*256	newlist
        CHARACTER*42    newssmisgprf7
        INTEGER*4       icnt1
C
	LOGICAL		opn, there

        character*8 sid
        integer id

C***********************************************************************
C       Set the job ID to a dummy value in case it is needed before the
C       actual value is read; modified for Joyce.

        farg1='Incorrect number of command-line arguments; exiting'
C       farg1='L3B42main0ss_dummy_jobid - job failed before job ID read'
C
C***********************************************************************
C	Get the file name containing the command-line arguments.  If
C	there's an error, print an error message and terminate
C	L3B42main0ss execution.
C
	nargs = IARGC ()
C
c	IF  (nargs .NE. 1) THEN
 	IF  (nargs .NE. 2) THEN
            WRITE(*,*) farg1
            STOP
	END IF
C
 
	CALL GETARG (1, cinfile)
        call getarg(2, sid)
        read(sid, *) id
 
C
C***********************************************************************
C	Open the ASCII file containing the L3B42main0ss command-line
C	arguments.  First, find an open file unit number.
C
	opn = .TRUE.
	iunit = 0
C

	DO WHILE (opn)
	    iunit = iunit + 1
	    INQUIRE (iunit, OPENED = opn)
	END DO
 
C
	OPEN (UNIT = iunit, FILE = cinfile, FORM = 'FORMATTED',
     +	      ACCESS = 'SEQUENTIAL', ERR = 30, IOSTAT = ios)

C
C***********************************************************************
C	Determine the number of command-line arguments.  Then, rewind
C	the file and ingest the input arguments.  If there's an error
C	in the number of command-line arguments, print an error message
C	and terminate L3B42main0ss execution.
C
	icount = 0
C
  10	READ (iunit, 100, ERR = 30, END = 20) cdummy
  	IF  (cdummy .NE. ' ') THEN
  	    icount = icount + 1
  	    GO TO 10
	END IF
C
  20	CONTINUE

C
	REWIND (iunit)

C
	iret = 0
	ninfile = 0
        farg2 = 'F16'
	farg4 = '19500101T00:00:00'
	farg5 = '20500101T23:59:59'
        farg7 = 'N'
 
 	DO i = 1, icount
 
 	    READ (iunit, 101, ERR = 30) cstring
 	    CALL ST_CLST (cstring, '=', '999', 2, ckp, nin, iret)
 	    IF  (nin .NE. 2) THEN
 		WRITE(*,*) 'Keyword=Parameter format incorrect; exiting'
                STOP
 	    END IF
 
 	    CALL ST_LSTR (ckp(1), l_key, iret)
            IF (iret .NE. 0) THEN
               WRITE(*,*) 'Error determining file name length; exiting'
               STOP
            ENDIF
 
 	    CALL ST_LSTR (ckp(2), l_parm, iret)
            IF (iret .NE. 0) THEN
               WRITE(*,*) 'Error determining file name length; exiting'
               STOP
            ENDIF
 
 	    IF  (ckp(1)(1:l_key) .EQ. 'job_id') THEN
 	    	farg1 = ckp(2)(1:l_parm)
 	    ELSE IF (ckp(1)(1:l_key) .EQ. 'satellite_id') THEN
 		farg2 = ckp(2)(1:l_parm)
 	    ELSE IF  (ckp(1)(1:l_key) .EQ. 'infile') THEN
                IF  (ninfile .GT. 10000) THEN
                    WRITE(*,*)
     &              'Number of input files cannot exceed 10000; exiting'
                    STOP
                END IF
                ninfile = ninfile + 1
 
                farg3(ninfile) = ckp(2)(1:l_parm)
 
  	    ELSE IF  (ckp(1)(1:l_key) .EQ. 'start_time') THEN
 	    	farg4 = ckp(2)(1:l_parm)
 	    ELSE IF  (ckp(1)(1:l_key) .EQ. 'end_time') THEN
 	    	farg5 = ckp(2)(1:l_parm)
 	    ELSE IF  (ckp(1)(1:l_key) .EQ. 'outdir') THEN
 	    	farg6 = ckp(2)(1:l_parm)
            ELSE IF  (ckp(1)(1:l_key) .EQ. 'debug_flag') THEN
                farg7 = ckp(2)(1:l_parm)
 	    ELSE
 		WRITE(*,*) 'Invalid input keyword; exiting'
                STOP
 	    END IF
 
 	END DO
 
c    Open file new orbit files

c     newlist = '/cpc/prod_tst/rjoyce/SSMIS_RH6/source/input_TDRfiles_dm
c    &spID'
c     write(newlist(58:59),'(i2.2)') id

      newlist = '../source/input_TDRfiles_dmspID'
      write(newlist(30:31),'(i2.2)') id
  
       print*, 'newlist=',newlist
 
      inquire (file=newlist, exist=there)

      if (there) then
       print*, 'newlist=',newlist
       open(12,file=newlist)
       rewind (12)
      else
       write (6,'('' no new input TDR files for DMSP '',i8)') id
       stop731
      endif

      ninfile  = 0
 
      do icnt1 = 1, 9999
       read (12,'(a42)',end=250) newssmisgprf7
       ninfile = ninfile + 1
 
c      farg0(1:67)='/cpc/prod_tst/cpcsat/cmorph/data/nesdis/ssmi/gprof7/
c    &dmspID/TDRPROC/'
c     write(farg0(57:58),'(i2.2)') id
 
c      farg0(1:66) ='/cpc/prod_tst/rjoyce/RH5_testing/cmorph/SSMIS/data/
c    &dmspID/TDRPROC/'
c     write(farg0(56:57),'(i2.2)') id
c      write(farg0(67:108),'(a42)') newssmisgprf7
 
c      farg0(1:51)='/cpc/prod_tst/rjoyce/SSMIS_RH6/data/dmspID/TDRPROC/'
c     write(farg0(41:42),'(i2.2)') id
c      write(farg0(52:93),'(a42)') newssmisgprf7
 
c123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123
c/cpc/prod_tst/rjoyce/SSMIS_RH6/data/dmspID/TDRPROC/NPR.TDRN.SA.D14351.S1714.E1858.B5760708.NS
c../data/dmspID/TDRPROC/NPR.TDRN.SA.D14351.S1714.E1858.B5760708.NS
       farg0(1:23)='../data/dmspID/TDRPROC/'
      write(farg0(13:14),'(i2.2)') id
       write(farg0(24:65),'(a42)') newssmisgprf7
 
       farg3(ninfile) = farg0
       write(6,'(''input TDR file '',a93)') farg3(ninfile)
      enddo
 250  continue
c     if (icnt1.eq.icnt1) stop856
      close(12)
C
	GO TO 40
C
  30	WRITE(*,*)
     &    'Error opening or reading input command-line argument file; ',
     &    'exiting'
        STOP
C
  40	CONTINUE
C
	CLOSE (iunit)
C
 100	FORMAT (A1)
 101	FORMAT (A256)
C
	RETURN
	END
