      ! Screening subroutine for ocean surface (sfctype = 0)

      subroutine screen_ocean(nwork, Tc, sfctype, sfckind, frzheight,
     &            pixel_status, rain_status)

      implicit none

      include 'parameters.inc'

      integer     nwork
      real        Tc(NPIX, MAX_SCANS, NCHAN)
      integer*1   sfctype(NPIX, MAX_SCANS)
      integer*1   sfckind(NPIX, MAX_SCANS)
      real        frzheight(NPIX, MAX_SCANS)
      integer*2   pixel_status(NPIX, MAX_SCANS)
      integer*2   rain_status(NPIX, MAX_SCANS)

      integer     lin, pix

      logical     app_sfc
      real        T19H, T19V, T22V, T37H, T37V, T85H
      real        d85_37, lwp, lwp_max

      real        WARM85_OC, T22_COLD, T37_COLD
      real        AMB_HI, AMB_LO, AMB_INT
      real        DT_OC, PCP_INT

      integer     MASKS, MASKP, MASKI, MASKO, MASKC

c     Set values for screens that will be used for rain_status.
c     Masks imply that no rain is possible so mask values < 0.

      MASKS = -21
      MASKP = -41
      MASKI = -31
      MASKO = -51
      MASKC = -61

c     Set threshold values needed by the screening algorithm
c     The added values are for Tbs.

      WARM85_OC = 262.
      T22_COLD  = 192. + 0.      ! This may be a bug is GSCAT
      T37_COLD  = 185. + 1.7
      AMB_HI    = 262. + 7.1
      AMB_LO    = 255. + 6.9
      AMB_INT   = 158. + 5.3
      DT_OC     =   0. + 0.5
      PCP_INT   =  38. - 0.1


      do lin = 1, nwork
        do pix = 1, NPIX
           if ( pixel_status(pix,lin) .lt. 0 ) goto 10

           ! Identify applicable surfaces.  This screen is
           ! for ocean surfaces only.

           app_sfc = .FALSE.
           if (sfctype(pix,lin) .EQ. 0) app_sfc = .TRUE.
           ! but skip pixels that might have ice.  They are
           ! screened separately under the ice screen.
           if ( sfckind(pix,lin) .eq. 04 ) app_sfc = .FALSE. 

           if ( app_sfc ) then

              ! Define constants used for screening
              T19H = Tc(pix,lin,1)
              T19V = Tc(pix,lin,2)  
              T22V = Tc(pix,lin,3)
              T37H = Tc(pix,lin,4)
              T37V = Tc(pix,lin,5)
              T85H = Tc(pix,lin,6)
              d85_37 = T85H-T37H 

              ! Check for unusually cold surface backgrounds
              ! This screen can get overwritten if the pixel
              ! is found to be clear of rain (i.e. other screens
              ! are still checked.

              if (frzheight(pix,lin) .lt. 500) then
                rain_status(pix,lin) = 51
              endif


              !  Check for low cloud liquid water contents.  This  
              !  screen works by computing the integrated cloud water 
              !  based on published literature {Hargens '94}.  If  
              !  the intergate lwp < threshold, then the pixel is 
              !  assumed to be rain free.  Because of algorithm
              !  errors for high emission pixels, some additional
              !  screens are needed.

              !  Assure that lwp test can be applied properly
              if ((T22V .ge. 280 ) .or. (T37V .ge. 280)) then
c              if ((T22V .ge. 285. ) .or. (T37V .ge. 285.)) then
                  rain_status(pix,lin) = MASKO
                  goto 10
              endif 
              lwp = 0.399635*log(280. - T22V) - 
     &                1.40692*log(280. - T37V) + 4.299
c              lwp = 0.399635*log(285. - T22V) - 
c     $                1.40692*log(285. - T37V) + 4.299
              lwp = 2.0 * lwp

              !  Define max liq. water content based on frz. hght
              lwp_max = 0.25*frzheight(pix,lin)/4000
              if ((lwp .lt. lwp_max) .and. (T19H .lt. 200.)) then
                 rain_status(pix,lin) = MASKO
                 goto 10
              endif


              !  Additional screens come from GSCAT - they are
              !  meant to insure that cold (either clear ocean
              !  or possibly ice) surfaces are either screened or 
              !  flagged if there is ambiguity in the signal.
              !  first screen deals with warm Tb at 85 but 
              !  unusually low 22 GHz.  The retrieval will be 
              !  defined as ambiguous

              if ((T85H .gt. WARM85_OC).and.(T22V .lt. AMB_HI)) then
                 rain_status(pix,lin) = 0

              !  If the 22 GHz is too cold, then it is likely ice

              elseif (T22V .le. T22_COLD) then
                 rain_status(pix,lin) = MASKI

              !  If no scattering is present (T85 > T37) and the 
              !  37 GHz is very cold, then clear ocean likely

              elseif ((D85_37 .gt. DT_OC).and.(T37H .le. T37_COLD)) then
                 rain_status(pix,lin) = MASKO

              !  Test for Grody light rain.  If it is not light
              !  rain, then test for cold ice.  Cold ice is set
              !  to ambiguous since it should not occur.

              elseif (T22V .gt. (PCP_INT + 0.88*T19V)) then
                 rain_status(pix,lin) = 0
              elseif ((T22V .lt. AMB_LO) .and.
     &                     (T22V .lt. (AMB_INT + 0.49*T85H))) then
                 rain_status(pix,lin) = 54
              endif


           end if
  10    end do
      end do

      return
      end


