	SUBROUTINE T2SEC1987  ( itime, nsec, iret )
C************************************************************************
C* T2SEC2K  Convert 6-integer date/time to seconds from 1987010100	*
C*									*
C* This subroutine converts 6-integer time (YYYY,MM,DD,HH,MM,SS) to	*
C* seconds since the start of 1 Jan. 1987.  If a 2-digit YY is passed	*
C* in, values below 50 have 2000 added, and the rest have 1900 added.	*
C*									*
C* T2SEC2K  ( itime, nsec, iret )					*
C*									*
C* Input parameters:							*
C*   itime	INT4*	6-integer time: YYYY,MM,DD,HH,MM,SS		*
C*									*
C* Output parameters:							*
C*   nsec	INT4	Corresponding number of seconds from the start	*
C*			of 1987 (may be <0)				*
C*   iret	INT	Return code: 0 = normal				*
C*				    -1 = stop				*
C**									*
C* Log:									*
C* G.Huffman/SSAI	 2/04	Consolidate, update TIMS87.F, IDAYS.F	*
C* E.Nelkin/SSAI        12/09   Modify T2SEC2K                          *
C************************************************************************
	IMPLICIT	NONE
	INTEGER*4	itime (6), nsec, iret
	INTEGER*4	iymd,      jyyyy, jday, jsec, leap1987,
     +			leapyyyy,  iday,  isec, nday, leapdex, i,
     +			MONTH (12, 2)
	DATA		MONTH
     +			/ 0,31,59,90,120,151,181,212,243,273,304,334,
     +			  0,31,60,91,121,152,182,213,244,274,305,335 /
C
	iret = 0
C
C	Set the year, allowing for a 2-digit YY; values <50 are
C	assumed to be in the 21st century; the rest in the 20th.
C
	IF  ( itime (1) .LT. 50 )  THEN
	    jyyyy = itime (1) + 2000
	  ELSE IF  ( itime (1) .LT. 100 )  THEN
	    jyyyy = itime (1) + 1900
	  ELSE
	    jyyyy = itime (1)
	END IF
C
C	Observing leap year, get Julian day (day of year), then seconds
C	into the day.
C
	IF  ( MOD ( jyyyy, 4 ) .NE. 0 )  THEN
	    leapdex = 1
	  ELSE
	    leapdex = 2
	END IF
	jday = MONTH (itime (2), leapdex) + itime (3)
	jsec = itime (4) * 3600 + itime (5) * 60 + itime (6)
C
C	Set number of leap days in previous years from 1987 to the
C	input year.  Then compute the number of days from the start
C	of 1987 and convert to seconds and add the current day's
C	seconds.
C
	leap1987 = (1987  - 1) / 4 + 1
	leapyyyy = (jyyyy - 1) / 4 + 1
	nday     = (jyyyy - 1987) * 365 + leapyyyy - leap1987 + jday - 1
	nsec     = nday * 86400 + jsec
C
	RETURN
	END
